@@ -159,26 +159,29 @@ var searchData=
   ['stringresourcewithlocation_156',['StringResourceWithLocation',['../servicecom_1_1sun_1_1star_1_1resource_1_1StringResourceWithLocation.html',1,'com::sun::star::resource']]],
   ['stringresourcewithstorage_157',['StringResourceWithStorage',['../servicecom_1_1sun_1_1star_1_1resource_1_1StringResourceWithStorage.html',1,'com::sun::star::resource']]],
   ['strokeattributes_158',['StrokeAttributes',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html',1,'com::sun::star::rendering']]],
-  ['style_159',['Style',['../servicecom_1_1sun_1_1star_1_1style_1_1Style.html',1,'com::sun::star::style']]],
-  ['stylefamilies_160',['StyleFamilies',['../servicecom_1_1sun_1_1star_1_1style_1_1StyleFamilies.html',1,'com::sun::star::style']]],
-  ['stylefamily_161',['StyleFamily',['../servicecom_1_1sun_1_1star_1_1style_1_1StyleFamily.html',1,'com::sun::star::style']]],
-  ['subincrement_162',['SubIncrement',['../structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html',1,'com::sun::star::chart2']]],
-  ['subject_163',['Subject',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Subject.html',1,'com::sun::star::text::textfield::docinfo']]],
-  ['submissionpropertyhandler_164',['SubmissionPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1SubmissionPropertyHandler.html',1,'com::sun::star::form::inspection']]],
-  ['submitbutton_165',['SubmitButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1SubmitButton.html',1,'SubmitButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html',1,'SubmitButton']]],
-  ['subtitleshape_166',['SubtitleShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SubtitleShape.html',1,'com::sun::star::presentation']]],
-  ['subtotalcolumn_167',['SubTotalColumn',['../structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html',1,'com::sun::star::sheet']]],
-  ['subtotaldescriptor_168',['SubTotalDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor.html',1,'com::sun::star::sheet']]],
-  ['subtotalfield_169',['SubTotalField',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalField.html',1,'com::sun::star::sheet']]],
-  ['subtotalfieldsenumeration_170',['SubTotalFieldsEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalFieldsEnumeration.html',1,'com::sun::star::sheet']]],
-  ['svgtools_171',['SvgTools',['../servicecom_1_1sun_1_1star_1_1graphic_1_1SvgTools.html',1,'com::sun::star::graphic']]],
-  ['symbol_172',['Symbol',['../structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html',1,'com::sun::star::chart2']]],
-  ['symboldescriptor_173',['SymbolDescriptor',['../structcom_1_1sun_1_1star_1_1formula_1_1SymbolDescriptor.html',1,'com::sun::star::formula']]],
-  ['syncdbussessionhelper_174',['SyncDbusSessionHelper',['../serviceorg_1_1freedesktop_1_1PackageKit_1_1SyncDbusSessionHelper.html',1,'org::freedesktop::PackageKit']]],
-  ['synchronousframeloader_175',['SynchronousFrameLoader',['../servicecom_1_1sun_1_1star_1_1frame_1_1SynchronousFrameLoader.html',1,'com::sun::star::frame']]],
-  ['systemclipboard_176',['SystemClipboard',['../servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1SystemClipboard.html',1,'com::sun::star::datatransfer::clipboard']]],
-  ['systemdependentxwindow_177',['SystemDependentXWindow',['../structcom_1_1sun_1_1star_1_1awt_1_1SystemDependentXWindow.html',1,'com::sun::star::awt']]],
-  ['systemintegration_178',['SystemIntegration',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SystemIntegration.html',1,'com::sun::star::configuration::backend']]],
-  ['systemshellexecute_179',['SystemShellExecute',['../servicecom_1_1sun_1_1star_1_1system_1_1SystemShellExecute.html',1,'com::sun::star::system']]],
-  ['systemshellexecuteexception_180',['SystemShellExecuteException',['../exceptioncom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteException.html',1,'com::sun::star::system']]]
+  ['struct_159',['Struct',['../structorg_1_1libreoffice_1_1embindtest_1_1Struct.html',1,'org::libreoffice::embindtest']]],
+  ['structlong_160',['StructLong',['../structorg_1_1libreoffice_1_1embindtest_1_1StructLong.html',1,'org::libreoffice::embindtest']]],
+  ['structstring_161',['StructString',['../structorg_1_1libreoffice_1_1embindtest_1_1StructString.html',1,'org::libreoffice::embindtest']]],
+  ['style_162',['Style',['../servicecom_1_1sun_1_1star_1_1style_1_1Style.html',1,'com::sun::star::style']]],
+  ['stylefamilies_163',['StyleFamilies',['../servicecom_1_1sun_1_1star_1_1style_1_1StyleFamilies.html',1,'com::sun::star::style']]],
+  ['stylefamily_164',['StyleFamily',['../servicecom_1_1sun_1_1star_1_1style_1_1StyleFamily.html',1,'com::sun::star::style']]],
+  ['subincrement_165',['SubIncrement',['../structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html',1,'com::sun::star::chart2']]],
+  ['subject_166',['Subject',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Subject.html',1,'com::sun::star::text::textfield::docinfo']]],
+  ['submissionpropertyhandler_167',['SubmissionPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1SubmissionPropertyHandler.html',1,'com::sun::star::form::inspection']]],
+  ['submitbutton_168',['SubmitButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1SubmitButton.html',1,'SubmitButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html',1,'SubmitButton']]],
+  ['subtitleshape_169',['SubtitleShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SubtitleShape.html',1,'com::sun::star::presentation']]],
+  ['subtotalcolumn_170',['SubTotalColumn',['../structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html',1,'com::sun::star::sheet']]],
+  ['subtotaldescriptor_171',['SubTotalDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor.html',1,'com::sun::star::sheet']]],
+  ['subtotalfield_172',['SubTotalField',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalField.html',1,'com::sun::star::sheet']]],
+  ['subtotalfieldsenumeration_173',['SubTotalFieldsEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalFieldsEnumeration.html',1,'com::sun::star::sheet']]],
+  ['svgtools_174',['SvgTools',['../servicecom_1_1sun_1_1star_1_1graphic_1_1SvgTools.html',1,'com::sun::star::graphic']]],
+  ['symbol_175',['Symbol',['../structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html',1,'com::sun::star::chart2']]],
+  ['symboldescriptor_176',['SymbolDescriptor',['../structcom_1_1sun_1_1star_1_1formula_1_1SymbolDescriptor.html',1,'com::sun::star::formula']]],
+  ['syncdbussessionhelper_177',['SyncDbusSessionHelper',['../serviceorg_1_1freedesktop_1_1PackageKit_1_1SyncDbusSessionHelper.html',1,'org::freedesktop::PackageKit']]],
+  ['synchronousframeloader_178',['SynchronousFrameLoader',['../servicecom_1_1sun_1_1star_1_1frame_1_1SynchronousFrameLoader.html',1,'com::sun::star::frame']]],
+  ['systemclipboard_179',['SystemClipboard',['../servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1SystemClipboard.html',1,'com::sun::star::datatransfer::clipboard']]],
+  ['systemdependentxwindow_180',['SystemDependentXWindow',['../structcom_1_1sun_1_1star_1_1awt_1_1SystemDependentXWindow.html',1,'com::sun::star::awt']]],
+  ['systemintegration_181',['SystemIntegration',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SystemIntegration.html',1,'com::sun::star::configuration::backend']]],
+  ['systemshellexecute_182',['SystemShellExecute',['../servicecom_1_1sun_1_1star_1_1system_1_1SystemShellExecute.html',1,'com::sun::star::system']]],
+  ['systemshellexecuteexception_183',['SystemShellExecuteException',['../exceptioncom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteException.html',1,'com::sun::star::system']]]
 ];
